@@ -24,5 +24,5 @@ class AppMainWindow(Model):
         super().__init__(*args, **kwargs)
 
         self.class_name = self.__class__.__name__
-        if self.appImageDir == None:
+        if self.appImageDir is None:
             self.appImageDir = f'/static/{self.image_dir_name}/images/'
