@@ -16,7 +16,6 @@ from isc_common.datetime import DateToStr
 from isc_common.http.DSRequest import DSRequest
 from isc_common.http.RPCResponse import RPCResponseConstant
 from isc_common.ws.webSocket import WebSocket
-from kaf_pas.planing.models.status_operation_types import Status_operation_types
 from tracker.models.messages_state import Messages_state
 from tracker.models.messages_theme import Messages_theme
 from twits.models.chat_user_user import Chat_user_user
@@ -28,8 +27,9 @@ logger = logging.getLogger(__name__)
 
 class LoginRequest(DSRequest):
     def __init__(self, request):
-        from reports.models.jasper_reports_users import Jasper_reports_users
         from django.forms import model_to_dict
+        from kaf_pas.planing.models.status_operation_types import Status_operation_types
+        from reports.models.jasper_reports_users import Jasper_reports_users
 
         DSRequest.__init__(self, request)
         data = self.get_data()
@@ -50,7 +50,7 @@ class LoginRequest(DSRequest):
                     # if len(visitors_all) > 1:
                     #     Visitor.objects.using('history').filter(username=login).delete()
 
-                    if settings.FREQUENCY_OF_POLLING_UNREAD_MESSAGES == None:
+                    if settings.FREQUENCY_OF_POLLING_UNREAD_MESSAGES is None:
                         settings.FREQUENCY_OF_POLLING_UNREAD_MESSAGES = 1000 * 60 * 3
 
                     visitors = [visitor.ip_address for visitor in Visitor.objects.using('history').filter(username=login).exclude(ip_address=ip)]
@@ -61,6 +61,7 @@ class LoginRequest(DSRequest):
                     else:
 
                         operations_statuses = []
+
                         for status_operation_types in Status_operation_types.objects.all():
                             operations_statuses.append(
                                 dict(
@@ -74,11 +75,11 @@ class LoginRequest(DSRequest):
                         from kaf_pas.ckk.models.locations_users import Locations_users
                         from kaf_pas.ckk.models.locations_view import Locations_view
                         if user.is_admin or user.is_develop:
-                            workshops=[]
+                            workshops = []
                         else:
                             workshops = [Locations_view.objects.get(id=Locations_users.location.id).workshop for Locations_users in Locations_users.objects.filter(user=user)]
                             workshops = [workshop.id if workshop else 0 for workshop in workshops]
-                            if len(workshops) == None:
+                            if len(workshops) is None:
                                 workshops = [-1]
 
                         self.response = dict(
@@ -104,7 +105,7 @@ class LoginRequest(DSRequest):
                             Operations_Plan=settings.OPERATIONS_PLAN.OPERSTYPES,
                             # progresses=[ProgressesManager.getRecord(item) for item in Progresses.objects.filter(user=user)],
                             status=RPCResponseConstant.statusSuccess,
-                            user__color=user.color if user.color != None and user.color != 'undefined' else 'black',
+                            user__color=user.color if user.color is not None and user.color != 'undefined' else 'black',
                             user_full_name=user.get_full_name,
                             user_short_name=user.get_short_name,
                             workshops=workshops,
