@@ -26,7 +26,8 @@ def User_FetchExclBots(request):
         DSResponse(
             request=request,
             data=User.objects.
-                exclude(props=User.props.bot, id=0).
+                exclude(props=User.props.bot).
+                exclude(id=0).
                 distinct().
                 get_range_rows11(
                 request=request,
