@@ -23,6 +23,7 @@ red = 'red'
 restarted = 'restarted'
 started = 'started'
 transferred = 'transferred'
+stoped = 'stoped'
 update = 'update'
 value_odd = 'value_odd'
 
@@ -33,11 +34,14 @@ def blinkString(text, blink=True, color="black", bold=False) -> Text:
     else:
         res = f'<div><strong><font color="{color}"</font>{text}</strong></div>'
 
-    if bold == True:
+    if bold is True:
         return f'<b>{res}</b>'
     else:
         return res
 
 
+def uuid5():
+    return UUID(bytes=os.urandom(16), version=4)
+
 def uuid4():
     return str(UUID(bytes=os.urandom(16), version=4)).upper().replace('-', '_')
