@@ -1,5 +1,9 @@
+import logging
+
 from django.utils.deprecation import MiddlewareMixin
 
+logger = logging.getLogger(__name__)
+
 
 class CorsMiddleware(MiddlewareMixin):
     def process_response(self, request, response):
