@@ -235,7 +235,7 @@ class CommonQuerySet(QuerySet):
     def getValue(self, criterion):
         value = criterion.get('value')
         operator = criterion.get('operator')
-        if value == None:
+        if value is None:
             if operator == "isNull":
                 return True
             elif operator == "notNull":
@@ -304,9 +304,9 @@ class CommonQuerySet(QuerySet):
     def get_criteria(self, json=dict()):
         data = json.get('data', dict())
         _data = dict()
-        if data != None:
+        if data is not None:
             for key, value in data.items():
-                if value != None and key != 'full_name':
+                if value is not None and key != 'full_name':
                     setAttr(_data, key, value)
         data = _data
         delAttr(data, 'ts')
@@ -428,9 +428,9 @@ class CommonQuerySet(QuerySet):
             data = request.json.get('data')
             deleted = False
             for remove_field in remove_fields:
-                if delAttr(data, remove_field) == True:
+                if delAttr(data, remove_field) is True:
                     deleted = True
-            if deleted == True:
+            if deleted is True:
                 setAttr(request.json, 'data', data)
 
         self.alive_only = request.alive_only
@@ -586,7 +586,7 @@ class CommonManager(Manager):
         data = request.get_data()
         _data = data.copy()
 
-        if _data.get('parent') != None and isinstance(_data.get('parent'), int):
+        if _data.get('parent') is not None and isinstance(_data.get('parent'), int):
             setAttr(_data, 'parent_id', _data.get('parent'))
             delAttr(_data, 'parent')
 
@@ -646,7 +646,7 @@ class CommonManager(Manager):
                 for prop in propsArr:
                     _prop = data.get(prop)
 
-                    if _prop == True:
+                    if _prop is True:
                         props = TurnBitOn(props, idx)
                     else:
                         props = TurnBitOff(props, idx)
@@ -802,7 +802,7 @@ class CommonManager(Manager):
 
         if field:
             # if field.null:
-            if field == None:
+            if field is None:
                 setAttr(_data, 'id', None)
                 res = _data
             else:
