@@ -11,8 +11,8 @@ logger = logging.getLogger(__name__)
 
 class AuditQuerySet(CommonQuerySet):
     def _check_ed_izm_qty(self, **kwargs):
-        if kwargs.get('ed_izm') != None and kwargs.get('qty') == None or kwargs.get('ed_izm') == None and kwargs.get('qty') != None:
-            raise Exception(f'ed_izm and qty not be along')
+        if kwargs.get('ed_izm') is not None and kwargs.get('qty') is None or kwargs.get('ed_izm') is None and kwargs.get('qty') is not None:
+            raise Exception(f'Единица измерения не может быть указана без количества')
 
     def __init__(self, model=None, query=None, using=None, hints=None, alive_only=True):
         self.alive_only = alive_only
@@ -25,7 +25,7 @@ class AuditQuerySet(CommonQuerySet):
                 if criterion.get('fieldName') == 'parent_id':
                     item_id = criterion.get('value')
                     if (item_id, int):
-                        criteria_lst = [criterion for criterion in _criteria if criterion.get('fieldName') == 'parent_id' and criterion.get('value') != None]
+                        criteria_lst = [criterion for criterion in _criteria if criterion.get('fieldName') == 'parent_id' and criterion.get('value') is not None]
                         if len(criteria_lst) > 0:
                             setAttr(json.get('data'), 'criteria', criteria_lst)
         return json
@@ -52,7 +52,7 @@ class AuditQuerySet(CommonQuerySet):
         return self.exclude(deleted_at=None)
 
     def update(self, **kwargs):
-        if kwargs.get('lastmodified') == None:
+        if kwargs.get('lastmodified') is None:
             setAttr(kwargs, 'lastmodified', timezone.now())
         return super().update(**kwargs)
 
@@ -109,11 +109,11 @@ class AuditModel(Model):
 
     @property
     def idHidden(self):
-        return not self == None
+        return not self is None
 
     @property
     def is_deleted(self):
-        return self.deleted_at != None
+        return self.deleted_at is not None
 
     class Meta:
         abstract = True
@@ -121,10 +121,12 @@ class AuditModel(Model):
     def soft_delete(self):
         self.deleted_at = timezone.now()
         self.save()
+        return self
 
     def soft_restore(self):
         self.deleted_at = None
         self.save()
+        return self
 
     objects = AuditManager()
     all_objects = AuditManager(alive_only=False)
