@@ -8,7 +8,7 @@ from isc_common import setAttr
 
 
 def DecimalToStr(value):
-    if value == None:
+    if value is None:
         return ''
 
     try:
@@ -27,7 +27,7 @@ def DecimalToStr(value):
 
 
 def StrToNumber(s1):
-    if s1 == None:
+    if s1 is None:
         return None
 
     if not isinstance(s1, str):
@@ -47,7 +47,7 @@ def StrToNumber(s1):
 
 
 def IntToNumber(s):
-    if s == None:
+    if s is None:
         return None
 
     if not isinstance(s, int):
@@ -57,7 +57,7 @@ def IntToNumber(s):
 
 
 def ToNumber(s):
-    if s == None:
+    if s is None:
         return 0
 
     if isinstance(s, int):
@@ -73,7 +73,7 @@ def ToNumber(s):
 
 
 def ToDecimal(s):
-    if s == None:
+    if s is None:
         return 0
 
     if isinstance(s, int):
@@ -89,7 +89,7 @@ def ToDecimal(s):
 
 
 def IntToDecimal(s):
-    if s == None:
+    if s is None:
         return None
 
     if not isinstance(s, int):
@@ -99,7 +99,7 @@ def IntToDecimal(s):
 
 
 def StrToInt(s):
-    if s == None:
+    if s is None:
         return None
     try:
         return int(s)
@@ -170,24 +170,42 @@ def compare_2_dict(dict1, dict2):
 
 
 class Set:
-    _lst = None
-    _set = None
+    _lst = []
+    _set = set()
 
-    def __init__(self, lst):
+    def __init__(self, lst=set()):
         if isinstance(lst, set):
-            self._set = set
+            self._set.clear()
+            for l in list(lst):
+                self._set.add(l)
 
         if isinstance(lst, list):
             self._lst = lst
 
+    def __str__(self):
+        if self._set is not None:
+            _lst = list(self._set)
+            _lst = [str(l) for l in _lst]
+
+            _str = ' , '.join(_lst)
+            return f'''({_str})'''
+        elif self._lst is not None:
+            _lst = [str(l) for l in self._lst]
+            _str = ' , '.join(_lst)
+            return f'''({_str})'''
+        else:
+            return '()'
+
+    def is_exists(self, element):
+        _len = len(self._set)
+        self._set.add(element)
+        return _len == len(self._set)
 
     @property
     def get_set_sorted_as_original(self):
-        if self._lst != None:
+        if self._lst is not None:
             return sorted(set(self._lst), key=self._lst.index)
-        elif self._set != None:
+        elif self._set is not None:
             return list(self._set)
         else:
             return []
-
-
