@@ -33,7 +33,7 @@ class Messages_admin_viewManager(MessagesManager):
             'date_create': record.lastmodified,
             'deliting': record.deliting,
             'editing': record.editing,
-            'enabled': record.state.code != 'closed' and record.state.code != 'readed' or enabled == True,
+            'enabled': record.state.code != 'closed' and record.state.code != 'readed' or enabled is True,
             'guid': str(record.guid).upper() if record.guid else None,
             'id': record.id,
             'importance__code': record.importance.code if record.importance else None,
