@@ -10,6 +10,7 @@ from isc_common.auth.models.user import User
 from isc_common.fields.related import ForeignKeyCascade
 from isc_common.http.DSRequest import DSRequest
 from isc_common.models.audit import AuditModel, AuditManager, AuditQuerySet
+from isc_common.number import DelProps
 from tracker.models.messages_theme import Messages_theme
 
 logger = logging.getLogger(__name__)
@@ -19,7 +20,7 @@ class Chat_user_userQuerySet(AuditQuerySet):
     def create(self, **kwargs):
         from twits.models.chat_user_user_theme import Chat_user_user_theme
 
-        user_sender=kwargs.get('user_sender')
+        user_sender = kwargs.get('user_sender')
         if not user_sender:
             user_sender = User.objects.get(id=kwargs.get('user_sender_id'))
 
@@ -80,54 +81,14 @@ class Chat_user_userManager(AuditManager):
             'user_reciver__email': record.user_reciver.email,
             'user_reciver__middle_name': record.user_reciver.middle_name,
             'user_reciver__last_login': record.user_reciver.last_login,
+            'props': record.props,
+            'compulsory_reading': record.props.compulsory_reading,
         }
-        return res
+        return DelProps(res)
 
     def get_queryset(self):
         return Chat_user_userQuerySet(self.model, using=self._db)
 
-    def deleteFromRequest(self, request, removed=None, function=None):
-        request = DSRequest(request=request)
-        qty = 0
-        res = 0
-        tuple_ids = request.get_tuple_ids()
-        with transaction.atomic():
-            for id, mode in tuple_ids:
-                if mode == 'hide':
-                    super().filter(id=id).soft_delete()
-                else:
-                    chat_user_user = Chat_user_user.objects.get(id=id)
-
-                    qty, _ = super().filter(id=id).delete()
-
-                    from twits.models.chats import ChatsManager
-                    ChatsManager.refresh_chat_menu(user=chat_user_user.user_reciver, logger=logger)
-                    ChatsManager.refresh_chat_menu(user=chat_user_user.user_sender, logger=logger)
-                res += qty
-            return res
-
-    def updateFromRequest(self, request, removed=None, function=None):
-        if not isinstance(request, DSRequest):
-            request = DSRequest(request=request)
-        data = request.get_data()
-
-        with transaction.atomic():
-            props = data.get('props')
-            if data.get('compulsory_reading') == True:
-                props |= Chat_user_user.props.compulsory_reading
-            else:
-                props &= ~Chat_user_user.props.compulsory_reading
-            _data = dict()
-            setAttr(_data, 'props', props)
-
-            res, _ = super().update_or_create(id=data.get('id'), defaults=_data)
-
-            from twits.models.chats import ChatsManager
-            ChatsManager.refresh_chat_menu(user=res.user_reciver, logger=logger)
-            ChatsManager.refresh_chat_menu(user=res.user_sender, logger=logger)
-
-            return data
-
     def createFromRequest(self, request):
         request = DSRequest(request=request)
         data = request.get_data()
@@ -156,14 +117,61 @@ class Chat_user_userManager(AuditManager):
 
             return data
 
+    def updateFromRequest(self, request, removed=None, function=None):
+        from twits.models.chats import ChatsManager
+
+        if not isinstance(request, DSRequest):
+            request = DSRequest(request=request)
+        data = request.get_data()
+
+        with transaction.atomic():
+            props = data.get('props')
+            if data.get('compulsory_reading') is True:
+                props |= Chat_user_user.props.compulsory_reading
+            else:
+                props &= ~Chat_user_user.props.compulsory_reading
+            _data = dict()
+            setAttr(_data, 'props', props)
+
+            res, _ = super().update_or_create(id=data.get('id'), defaults=_data)
+
+            ChatsManager.refresh_chat_menu(user=res.user_reciver, logger=logger)
+            ChatsManager.refresh_chat_menu(user=res.user_sender, logger=logger)
+
+            return _data
+
+    def deleteFromRequest(self, request, removed=None, function=None):
+        request = DSRequest(request=request)
+        qty = 0
+        res = 0
+        tuple_ids = request.get_tuple_ids()
+        with transaction.atomic():
+            for id, mode in tuple_ids:
+                if mode == 'hide':
+                    super().filter(id=id).soft_delete()
+                else:
+                    chat_user_user = Chat_user_user.objects.get(id=id)
+
+                    qty, _ = super().filter(id=id).delete()
+
+                    from twits.models.chats import ChatsManager
+                    ChatsManager.refresh_chat_menu(user=chat_user_user.user_reciver, logger=logger)
+                    ChatsManager.refresh_chat_menu(user=chat_user_user.user_sender, logger=logger)
+                res += qty
+            return res
+
+    @staticmethod
+    def props():
+        return BitField(flags=(
+            ('compulsory_reading', 'Обязательное прочтение'),  # 1
+        ), default=0, db_index=True)
+
 
 class Chat_user_user(AuditModel):
     user_sender = ForeignKeyCascade(User, related_name='user_sender_user')
     user_reciver = ForeignKeyCascade(User, related_name='user_reciver_user')
     common_id = PositiveIntegerField()
-    props = BitField(flags=(
-        ('compulsory_reading', 'Обязательное прочтение'),  # 1
-    ), default=0, db_index=True)
+    props = Chat_user_userManager.props()
 
     objects = Chat_user_userManager()
 
